
..
    This file maps contributor names to their URLs. It should mostly be used
    for core contributors, and occasionally for contributors who do not want
    their github page to be their URL target. Historically it was used to
    hyperlink all contributors' names, and ``:user:`` should now be preferred.
    It also defines other ReST substitutions.

.. role:: raw-html(raw)
   :format: html

.. role:: raw-latex(raw)
   :format: latex

.. |MajorFeature| replace:: :raw-html:`<span class="badge badge-success">Major Feature</span>` :raw-latex:`{\small\sc [Major Feature]}`
.. |Feature| replace:: :raw-html:`<span class="badge badge-success">Feature</span>` :raw-latex:`{\small\sc [Feature]}`
.. |Efficiency| replace:: :raw-html:`<span class="badge badge-info">Efficiency</span>` :raw-latex:`{\small\sc [Efficiency]}`
.. |Enhancement| replace:: :raw-html:`<span class="badge badge-info">Enhancement</span>` :raw-latex:`{\small\sc [Enhancement]}`
.. |Fix| replace:: :raw-html:`<span class="badge badge-danger">Fix</span>` :raw-latex:`{\small\sc [Fix]}`
.. |API| replace:: :raw-html:`<span class="badge badge-warning">API Change</span>` :raw-latex:`{\small\sc [API Change]}`


.. _Adam Li: https://adam2392.github.io
.. _Jong Shin: https://github.com/jshinm
.. _Sambit Panda: https://sampan.me
.. _SUKI-O : https://github.com/SUKI-O
.. _Ronan Perry : https://rflperry.github.io/
.. _Haoyin Xu : https://github.com/PSSF23
.. _Yuxin Bai : https://github.com/YuxinB
.. _Ryan Hausen : https://ryanhausen.github.io
